==> istio-model-v1alpha3-5.11.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterProxyMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class EnvoyFilterProxyMatchFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterProxyMatchFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterProxyMatchFluent<A>{
  public EnvoyFilterProxyMatchFluentImpl() {
  }
  public EnvoyFilterProxyMatchFluentImpl(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterProxyMatch instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withProxyVersion(instance.getProxyVersion()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> metadata;
  private java.lang.String proxyVersion;
  public A addToMetadata(java.lang.String key,java.lang.String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  public A addToMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null && map != null) { this.metadata = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  public A removeFromMetadata(java.lang.String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  public A removeFromMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getMetadata() {
    return this.metadata;
  }
  public <K,V>A withMetadata(java.util.Map<java.lang.String,java.lang.String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public java.lang.String getProxyVersion() {
    return this.proxyVersion;
  }
  public A withProxyVersion(java.lang.String proxyVersion) {
    this.proxyVersion=proxyVersion; return (A) this;
  }
  public java.lang.Boolean hasProxyVersion() {
    return this.proxyVersion != null;
  }
  
  /**
   * Method is deprecated. use withProxyVersion instead.
   */
  @java.lang.Deprecated
  public A withNewProxyVersion(java.lang.String arg0) {
    return (A)withProxyVersion(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterProxyMatchFluentImpl that = (EnvoyFilterProxyMatchFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (proxyVersion != null ? !proxyVersion.equals(that.proxyVersion) :that.proxyVersion != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  proxyVersion,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-5.12.4-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterProxyMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class EnvoyFilterProxyMatchFluentImpl<A extends io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterProxyMatchFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterProxyMatchFluent<A>{
  public EnvoyFilterProxyMatchFluentImpl() {
  }
  public EnvoyFilterProxyMatchFluentImpl(io.fabric8.istio.api.networking.v1alpha3.EnvoyFilterProxyMatch instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withProxyVersion(instance.getProxyVersion()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> metadata;
  private java.lang.String proxyVersion;
  public A addToMetadata(java.lang.String key,java.lang.String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  public A addToMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null && map != null) { this.metadata = new java.util.LinkedHashMap(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  public A removeFromMetadata(java.lang.String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  public A removeFromMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getMetadata() {
    return this.metadata;
  }
  public <K,V>A withMetadata(java.util.Map<java.lang.String,java.lang.String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new java.util.LinkedHashMap(metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public java.lang.String getProxyVersion() {
    return this.proxyVersion;
  }
  public A withProxyVersion(java.lang.String proxyVersion) {
    this.proxyVersion=proxyVersion; return (A) this;
  }
  public java.lang.Boolean hasProxyVersion() {
    return this.proxyVersion != null;
  }
  
  /**
   * Method is deprecated. use withProxyVersion instead.
   */
  @java.lang.Deprecated
  public A withNewProxyVersion(java.lang.String arg0) {
    return (A)withProxyVersion(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterProxyMatchFluentImpl that = (EnvoyFilterProxyMatchFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (proxyVersion != null ? !proxyVersion.equals(that.proxyVersion) :that.proxyVersion != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  proxyVersion,  super.hashCode());
  }
  
}
